An S4 class to represent Claims and Premiums for reinsurance computations.
# S4 method for Claims
show(object)The object to display
show: show method
clmData.table. Claims table. Contains at least 4 columns:
year: year associated with the considered claim;
portfolio: portfolio associated with the considered claim;
simulId: simulation id of the considered claim. Useful for stochastic modelling;
amount: amount of the considered claim.
prmData.table. Premiums table. Contains at least 3 columns:
year: year associated with the considered premium;
portfolio: portfolio associated with the considered premium;
amount: amount of the considered premium.
rnsData.table. Reinstatement amount table, that only concerns excess of loss treaties. Contains at least 2 columns:
year: year associated with the considered reinstatements;
simulId: simulation id of the considered reinstatement amount. Useful for stochastic modelling.
comData.table. Commissions amount table, that only concerns quota share treaties. Contains at least 2 columns:
year: year associated with the considered commission amount;
portfolio: portfolio associated with the considered commission.
trtVector. List of treaties applied to the Claims object.