Learn R Programming

reinsureR (version 0.1.0)

QS-class: Quota Share Treaty

Description

An S4 class to represent a Quota Share Treaty

Usage

# S4 method for QS
show(object)

Arguments

object

the object to display

Methods (by generic)

  • show: Quota Share Treaty: show method

Slots

csn_clm

Numeric. Cession rate on claims. Should be between 0 and 1.

csn_prm

Numeric. Cession rate on premiums. Should be between 0 and 1.

com

Numeric. Commission rate, applied on the part of premiums given to the reinsurer. Should be between 0 and 1.

ptf

Vector. List of portfolios on which the treaty is to be applied on.

trt

Character. Always equal to "QS". Identifier for the type of treaty.