An S4 class to represent a Stop Loss Treaty
# S4 method for SL
show(object)the object to display
show: Stop Loss Treaty: show method
dedNumeric. Deductible amount of the treaty. Should be superior to 0.
limNumeric. Limit amount for the treaty. Should be superior to 0. May be equal to Inf.
prmNumeric. Premium rate, which represents the proportion of the premium given to the reinsurer as price for the treaty. Should be between 0 and 1.
ptfVector. List of portfolios on which the treaty is to be applied on.
trtCharacter. Always equal to "SL". Identifier for the type of treaty