An S4 class to represent an Excess of Loss Treaty
# S4 method for XL
show(object)the object to display
show: Excess of Loss Treaty: show method
dedNumeric. Deductible amount of the treaty. Should be superior to 0.
limNumeric. Limit amount for the treaty. Should be superior to 0. May be equal to Inf.
aalNumeric. Annual Aggregate Deductible amount of the treaty. Should be superior to 0.
aadNumeric. Annual Aggregate Limit amount for the treaty. Should be superior to 0. May be equal to Inf.
rnsNumeric vector. Reinstatement prices. Vector of lentgh equals to the number of reinstatements with each value equals the price of the reinstatement.
prmNumeric. Premium rate, which represents the proportion of the premium given to the reinsurer as price for the treaty. Should be between 0 and 1.
ptfVector. List of portfolios on which the treaty is to be applied on.
trtCharacter. Always equal to "SL". Identifier for the type of treaty