powered by
qs defines an object of class QS (QS-class).
qs
QS
QS-class
qs(csn_clm, csn_prm = "auto", com = 0, ptf = "all")
Numeric. Cession rate on claims. Should be between 0 and 1.
Numeric. Cession rate on premiums. Should be between 0 and 1. Default value set to csn_clm.
csn_clm
Numeric. Commission rate, applied on the part of premiums given to the reinsurer. Should be between 0 and 1. Default value set to 0.
Vector. List of portfolios on which the treaty is to be applied on. Default value set to all.
An object of class QS (QS-class), initialized with the values given in input. Its basic methods are:
show
# NOT RUN { treaty_1 <- qs(0.8, com = 0.25) treaty_1 # }
Run the code above in your browser using DataLab