powered by
sl defines an object of class SL (SL-class), which represents a Stop Loss treaty.
sl
SL
SL-class
sl(ded = Inf, lim = Inf, prm = 0, ptf = "all")
Numeric. Deductible amount of the treaty. Should be superior to 0.
Numeric. Limit amount for the treaty. Should be superior to 0. May be equal to Inf.
Inf
Numeric. Premium rate, which represents the proportion of the premium given to the reinsurer as price for the treaty. Should be between 0 and 1.
Vector. List of portfolios on which the treaty is to be applied on. Default value set to all.
An object of class SL (SL-class), initialized with the values given in input. Its basic methods are:
show
# NOT RUN { treaty_1 <- sl(ded = 100000, lim = 20000, prm = 0.01, ptf = "all") treaty_1 # }
Run the code above in your browser using DataLab