Numeric. Deductible amount of the treaty. Should be superior to 0.
lim
Numeric. Limit amount for the treaty. Should be superior to 0. May be equal to Inf.
aal
Numeric. Annual Aggregate Deductible amount of the treaty. Should be superior to 0.
aad
Numeric. Annual Aggregate Limit amount for the treaty. Should be superior to 0. May be equal to Inf.
prm
Numeric. Premium rate, which represents the proportion of the premium given to the reinsurer as price for the treaty. Should be between 0 and 1.
rns
Numeric vector. Reinstatement prices. Vector of lentgh equals to the number of reinstatements with each value equals the price of the reinstatement.
ptf
Vector. List of portfolios on which the treaty is to be applied on. Default value set to all.
Value
An object of class XL (XL-class), initialized with the values given in input. Its basic methods are:
show
Details
Reinstatements are the number of time the limit can be reconstructed. The vector given for this parameter will be an indication of the price for each reinstatement. For example, a rns value of c(0, 1) will give one free reinstatement and one reinstatement paid 100% of the premium before totally consuming the limit.