QS-class: Quota Share Treaty
Description
An S4 class to represent a Quota Share Treaty
Usage
# S4 method for QS
show(object)
Slots
csn_clmNumeric. Cession rate on claims. Should be between 0 and 1.
csn_prmNumeric. Cession rate on premiums. Should be between 0 and 1.
comNumeric. Commission rate, applied on the part of premiums given to the reinsurer. Should be between 0 and 1.
ptfVector. List of portfolios on which the treaty is to be applied on.
trtCharacter. Always equal to "QS". Identifier for the type of treaty.